package com.docus.server.api.scheduling.management;

import com.docus.infrastructure.web.request.SearchRequest;
import com.docus.infrastructure.web.response.PageResult;
import com.docus.server.entity.scheduling.management.TaskTerminatorErrorLog;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;


/**
 * <p>
 * 采集器异常日志（采集器终端） API
 * </p>
 *
 * @author AutoGenerator
 * @since 2023-07-12
 */
@Api(value = "采集器异常日志（采集器终端）任务管理接口", tags = "采集器异常日志（采集器终端）任务管理接口")
@FeignClient(value = "collector-scheduling-management", contextId = "collector-scheduling-management.TaskTerminatorErrorLogApi")
@RequestMapping("/sch/taskTerminatorErrorLog")
public interface TaskTerminatorErrorLogApi {

    /**
     * 按主键查询
     *
     * @param id 主键id
     * @return 实体
     */
    @ApiOperation("按主键查询")
    @GetMapping("/find/{id}")
    TaskTerminatorErrorLog findById(@PathVariable(value = "id") String id);

    /**
     * 关键字搜素
     *
     * @param searchRequest 搜索参数
     * @return 分页列表
     */
    @ApiOperation("关键字搜素")
    @PostMapping("/search")
    PageResult<TaskTerminatorErrorLog> search(@RequestBody SearchRequest searchRequest);

    /**
     * 新增
     *
     * @param taskTerminatorErrorLog 新增参数
     * @return 成功或失败
     */
    @ApiOperation("新增")
    @PostMapping(value = "/add", headers = {"content-type=multipart/form-data"})
    @ApiImplicitParams({
        @ApiImplicitParam(name = "screenUrl", value = "截图文件", required = true, dataTypeClass = MultipartFile.class)
    })
    boolean add(@Validated TaskTerminatorErrorLog taskTerminatorErrorLog, @RequestPart("screenUrl") MultipartFile screenUrl);

    /**
     * 编辑
     *
     * @param taskTerminatorErrorLog 编辑参数
     * @return 成功或失败
     */
    @ApiOperation("编辑")
    @PutMapping("/edit")
    boolean edit(@RequestBody TaskTerminatorErrorLog taskTerminatorErrorLog);

    /**
     * 批量删除
     *
     * @param ids 主键ids
     * @return 成功或失败
     */
    @ApiOperation("批量删除")
    @DeleteMapping("/delete")
    int delete(@RequestBody List<String> ids);
}
